@@ -25,6 +25,11 @@
 #include <string>
 #include <string.h>
 
+/*!
+ \addtogroup libfaustcpp C++ interface for the tools API.
+ @{
+ */
+
 #ifdef _WIN32
 #define LIBEXPORT __declspec(dllexport)
 #else
@@ -36,7 +41,7 @@
  *
  * @param data - the string to be converted in SHA1 key
  *
- * @return the SHA key
+ * @return the SHA key.
  */
 LIBEXPORT std::string generateSHA1(const std::string& data);
 
@@ -51,7 +56,7 @@ LIBEXPORT std::string generateSHA1(const std::string& data);
  * @param sha_key - a SHA key to be filled by for the resulting DSP
  * @param error_msg - the error string to be filled
  *
- * @return the expanded DSP or an empty string in case of failure
+ * @return the expanded DSP or an empty string in case of failure.
  */
 LIBEXPORT std::string expandDSPFromFile(const std::string& filename, int argc, const char* argv[], std::string& sha_key,
                                         std::string& error_msg);
@@ -66,7 +71,7 @@ LIBEXPORT std::string expandDSPFromFile(const std::string& filename, int argc, c
  * @param sha_key - a SHA key to be filled by for the resulting DSP
  * @param error_msg - the error string to be filled
  *
- * @return the expanded DSP or a empty string in case of failure
+ * @return the expanded DSP or a empty string in case of failure.
  */
 LIBEXPORT std::string expandDSPFromString(const std::string& name_app, const std::string& dsp_content, int argc,
                                           const char* argv[], std::string& sha_key, std::string& error_msg);
@@ -79,7 +84,7 @@ LIBEXPORT std::string expandDSPFromString(const std::string& name_app, const std
  * @param argv - the array of parameters
  * @param error_msg - the error string to be filled
  *
- * @return the expanded DSP or an empty string in case of failure
+ * @return the expanded DSP or an empty string in case of failure.
  */
 LIBEXPORT bool generateAuxFilesFromFile(const std::string& filename, int argc, const char* argv[],
                                         std::string& error_msg);
@@ -92,7 +97,7 @@ LIBEXPORT bool generateAuxFilesFromFile(const std::string& filename, int argc, c
  * @param argv - the array of parameters
  * @param error_msg - the error string to be filled
  *
- * @return the expanded DSP or a empty string in case of failure
+ * @return the expanded DSP or a empty string in case of failure.
  */
 LIBEXPORT bool generateAuxFilesFromString(const std::string& name_app, const std::string& dsp_content, int argc,
                                           const char* argv[], std::string& error_msg);
@@ -112,4 +117,8 @@ extern "C" void freeCMemory(void* ptr);
 extern "C" LIBEXPORT void freeCMemory(void* ptr);
 #endif
 
+/*!
+ @}
+ */
+
 #endif
